Option Explicit
On Error Resume Next

Include "pva-agent-helper.vbs"

const VZSRV_SERVICE = "vzsrv"
Dim ANONYMIZE
ANONYMIZE = 0

LogProgress "Executing " & Wscript.ScriptName

ParseCommandLine

Dim dataDir, installDir, PVA_CMDLINE_CONF
dataDir = SafeGetDataDir(0)
installDir = SafeGetInstallDir(0)
If dataDir = "" or installDir = "" Then FailedQuit "Can not find agent installation path in registry."
	
PVA_CMDLINE_CONF = installDir & "\bin\pva.conf"

ConfigureVZ

If Err.number = 0 Then
	LogProgress Wscript.ScriptName & " finished succesfully"
	WScript.Quit 0
Else
	FailedQuitErr "Failed to configure PVA agent for Virtuozzo"
End If


'
' Functions
'
Sub ConfigureVZ()
	LogProgress "Starting PVA Agent for Virtuozzo configuration"

	' Stop service
	StopService PVA_SERVICE_NAME_SLAVE

	' Remove cached agent data
	If ANONYMIZE Then RemoveAgentData
	
	RegisterService PVA_SERVICE_NAME_SLAVE, PVA_DISPLAY_SERVICE_NAME_SLAVE, PVA_SERVICE_DESCRIPTION_SLAVE, _
		installDir & "\bin\pvaagentd.exe """ & PVA_CMDLINE_CONF & """", Null, Null, Array(VZSRV_SERVICE)
	
	StartService PVA_SERVICE_NAME_SLAVE

	Dim fso
	Set fso = CreateObject("Scripting.FileSystemObject")
	fso.CopyFile installDir & "\bin\pvareport.vbs", installDir & "\bin\vzagentCollectReport.vbs"
	fso.CopyFile installDir & "\bin\pvaprintreport.vbs", installDir & "\bin\vzagentInfoReport.vbs"

	LogProgress "PVA Agent for Virtuozzo configured succesfully"
End Sub

Sub RemoveAgentData
	Dim fso
	Dim folder
	Dim parentFolder
	Dim Value
	
	LogProgress "Removing cached VZAgent data"
	
	If ReadRegistryKey("HKLM\Software\SWsoft\Virtuozzo\VZPRIVATE", Value) <> 0 Then
			Value = vzlRootFolder & "\private"
	End If

	Set fso = CreateObject("Scripting.FileSystemObject")
	Set parentFolder = fso.GetFolder(Value)
	For Each folder in parentFolder.SubFolders
		DeleteFolder folder & "\.vza"
	Next
	
End Sub

Sub ParseCommandLine()
	If WScript.Arguments.Count() > 0 Then
		Dim i
		For i=0 To WScript.Arguments.Count()
			Select Case WScript.Arguments(i)
				Case "--anonymize"
					LogProgress "Anonymization requested - clean cached agent data"
					ANONYMIZE = 1
			End Select
		Next
	End If
End Sub
	
' Include vzlVBLib.vbs
Sub Include(cNameScript)
	On Error Resume Next
	Dim oFS, oFile
	
	cNameScript = Mid(Wscript.ScriptFullName, 1, InStrRev(Wscript.ScriptFullName, "\")) & cNameScript
	
	Set oFS = CreateObject("Scripting.Filesystemobject")
	
	Set oFile = oFS.OpenTextFile(cNameScript)
	If Err.number <> 0 Then
		WScript.Echo "Failed to open include file '" & cNameScript & "' - " & Err.source & ", " & Err.Description
		WScript.Quit(-1)
	End If
	
	ExecuteGlobal oFile.ReadAll()
	If Err.number <> 0 Then
		WScript.Echo "Failed to ExecuteGlobal include file '" & cNameScript & "' - " & Err.source & ", " & Err.Description
		WScript.Quit(-1)
	End If

	oFile.Close
End Sub
